# =====================================
# generator=datazen
# version=3.1.4
# hash=9e67da4714539646e56663e5f514af0d
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A tool for working with scalable vector graphics."
PKG_NAME = "svgen"
VERSION = "0.7.0"
